GKPlayMode enum

The playback mode for a GKController animation.

Determines how the animation progresses over time:

  • forward plays once from start to end.
  • reverse plays once from end to start.
  • loop repeats forward indefinitely.
  • pingPong alternates between forward and reverse indefinitely.
Inheritance
Available extensions

Values

forward → const GKPlayMode

Plays the animation forward once.

reverse → const GKPlayMode

Plays the animation in reverse once.

loop → const GKPlayMode

Loops the animation forward indefinitely.

pingPong → const GKPlayMode

Alternates forward and reverse indefinitely.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<GKPlayMode>
A constant List of the values in this enum, in order of their declaration.