GKEffect class abstract
Abstract base class for all GK visual effects.
Subclasses must implement build to return a widget that renders the effect driven by the provided GKController.
{@tool snippet}
class MyEffect extends GKEffect {
const MyEffect();
@override
Widget build(BuildContext context, GKController controller, {Widget? child}) {
return CustomPaint(
painter: MyPainter(controller: controller),
child: child,
);
}
}
{@end-tool}
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context, GKController controller, {Widget? child}) → Widget - Builds the widget tree for this effect.
-
dispose(
) → void - Override to release resources held by this effect.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited