GKManagedWidget class

A GKWidget wrapper that automatically adjusts effect intensity based on GKPerformanceManager quality changes.

Listens to GKPerformanceManager.qualityStream and sets the controller's intensity to:

{@tool snippet}

GKManagedWidget(
  effect: GlitchEffect(),
  trigger: GKTrigger.auto,
)

{@end-tool}

Inheritance

Constructors

GKManagedWidget({Key? key, required GKEffect effect, GKTrigger trigger = GKTrigger.auto, bool interactive = false, Widget? child, GKController? controller, Duration duration = const Duration(seconds: 2)})
Creates a GKManagedWidget.
const

Properties

child Widget?
An optional child widget rendered beneath the effect.
final
controller GKController?
An optional external controller.
final
duration Duration
The animation duration for an internally created controller.
final
effect GKEffect
The visual effect to render.
final
hashCode int
The hash code for this object.
no setterinherited
interactive bool
Whether the widget tracks pointer position.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trigger GKTrigger
How the animation is triggered.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<GKManagedWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited