GKQuality enum

Rendering quality tier used by GKPerformanceManager.

Maps to an effect intensity multiplier in GKManagedWidget:

  • high: full intensity (1.0).
  • medium: reduced intensity (0.6).
  • low: minimal intensity (0.3).
Inheritance
Available extensions

Values

high → const GKQuality

Full quality, intensity 1.0.

medium → const GKQuality

Reduced quality, intensity 0.6.

low → const GKQuality

Minimal quality, intensity 0.3.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<GKQuality>
A constant List of the values in this enum, in order of their declaration.