GKTrigger enum

Determines how a GKWidget starts its animation.

  • auto: animation starts immediately and loops.
  • onTap: animation plays on tap.
  • onHover: animation plays while the pointer hovers.
  • manual: animation is controlled externally via GKController.
Inheritance
Available extensions

Values

auto → const GKTrigger

Starts automatically and loops.

onTap → const GKTrigger

Plays on tap.

onHover → const GKTrigger

Plays while the pointer hovers over the widget.

manual → const GKTrigger

Controlled entirely by the caller.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<GKTrigger>
A constant List of the values in this enum, in order of their declaration.