noiseAmount property
The intensity of random noise grain overlaid on the image.
Values from 0.0 (no noise) to 1.0 (heavy static).
Implementation
final double noiseAmount;
The intensity of random noise grain overlaid on the image.
Values from 0.0 (no noise) to 1.0 (heavy static).
final double noiseAmount;