trackingError property
The strength of horizontal tracking error displacement.
Higher values produce more frequent and dramatic horizontal shifts.
Implementation
final double trackingError;
The strength of horizontal tracking error displacement.
Higher values produce more frequent and dramatic horizontal shifts.
final double trackingError;