time property

double get time

Elapsed time in seconds since the controller was created.

This value increases continuously and is used as the primary time uniform for shader-based effects.

Implementation

double get time => DateTime.now().difference(_startTime).inMicroseconds / 1e6;