MorphShapePainter class
A CustomPainter that morphs between two paths by interpolating sampled points.
Both fromPath and toPath are resampled to sampleCount evenly spaced points, then each point is linearly interpolated using progress. This produces smooth shape-to-shape transitions regardless of the original point counts.
{@tool snippet}
CustomPaint(
painter: MorphShapePainter(
fromPath: circlePath,
toPath: starPath,
progress: controller.value,
color: Colors.white,
),
)
{@end-tool}
- Inheritance
-
- Object
- Listenable
- CustomPainter
- MorphShapePainter
Constructors
- MorphShapePainter({required Path fromPath, required Path toPath, required double progress, required Color color, double strokeWidth = 2.0, bool filled = false, int sampleCount = 100})
- Creates a MorphShapePainter.
Properties
- color → Color
-
The stroke or fill color.
final
- filled → bool
-
Whether to fill the interpolated shape instead of stroking it.
final
- fromPath → Path
-
The starting shape path.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- progress → double
-
Interpolation progress from 0.0 (fromPath) to 1.0 (toPath).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleCount → int
-
The number of evenly spaced points sampled along each path.
final
- semanticsBuilder → SemanticsBuilderCallback?
-
Returns a function that builds semantic information for the picture drawn
by this painter.
no setterinherited
- strokeWidth → double
-
The stroke width used when filled is
false.final - toPath → Path
-
The target shape path.
final
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be notified when it is time to repaint.
inherited
-
hitTest(
Offset position) → bool? -
Called whenever a hit test is being performed on an object that is using
this custom paint delegate.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paint(
Canvas canvas, Size size) → void -
Called whenever the object needs to paint. The given Canvas has its
coordinate space configured such that the origin is at the top left of the
box. The area of the box is the size of the
sizeargument.override -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that the
object notifies when it is time to repaint.
inherited
-
shouldRebuildSemantics(
covariant CustomPainter oldDelegate) → bool -
Called whenever a new instance of the custom painter delegate class is
provided to the RenderCustomPaint object, or any time that a new
CustomPaint object is created with a new instance of the custom painter
delegate class (which amounts to the same thing, because the latter is
implemented in terms of the former).
inherited
-
shouldRepaint(
covariant MorphShapePainter oldDelegate) → bool -
Called whenever a new instance of the custom painter delegate class is
provided to the RenderCustomPaint object, or any time that a new
CustomPaint object is created with a new instance of the custom painter
delegate class (which amounts to the same thing, because the latter is
implemented in terms of the former).
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited